==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/mn.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\" хавтас руу бичих боломжгүй байна!",
    "Unknown filetype" : "Үл мэдэгдэх файлын төрөл",
    "Invalid image" : "буруу зураг",
    "Avatar image is not square" : "Хөрөг зураг дөрвөлжин биш",
    "today" : "өнөөдөр",
    "yesterday" : "өчигдөр",
    "last month" : "сүүлийн сар",
    "last year" : "сүүлийн жил",
    "seconds ago" : "секундийн өмнө",
    "File name is a reserved word" : "Файлын нэр нь нийцгүй  үг",
    "File name contains at least one invalid character" : "файлын нэр нь хамгийн багадаа нэг нь хүчингүй тэмдэгт агуулж байна",
    "File name is too long" : "Файлын нэр хэтэрхий урт байна",
    "Dot files are not allowed" : "Dot файлууд зөвшөөрөл байхгүй байна",
    "__language_name__" : "хэлний нэр",
    "Help" : "Туслах",
    "Apps" : "Аппликэйшинууд",
    "Settings" : "Тохиргоо",
    "Log out" : "гаргах",
    "Users" : "хэрэглэгч",
    "Unknown user" : "  хэрэглэгч",
    "Sharing" : "Түгээх",
    "Security" : "Хамгаалалт",
    "Personal info" : "Хувийн мэдээлэл",
    "Open »%s«" : "»%s« нээх",
    "Sunday" : "ням гариг",
    "Monday" : "даваа",
    "Tuesday" : "мягмар",
    "Wednesday" : "лхагва",
    "Thursday" : "пүрэв",
    "Friday" : "баасан",
    "Saturday" : "бямба",
    "June" : "Зургадугаар сар",
    "November" : "Арван нэгдүгээр сар",
    "a safe home for all your data" : "Таны өгөгдлүүдийн аюулгүй гэр",
    "Authentication error" : "Нотолгооны алдаа",
    "Storage is temporarily not available" : "Хадгалах төхөөрөмж нь түр хугацаанд ашиглах боломжгүй байна",
    "Create" : "Үүсгэх",
    "Delete" : "Устгах",
    "Share" : "Түгээх",
    "Verify" : "Шалнгах"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/lib/l10n/mn.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "\"config\" хавтас руу бичих боломжгүй байна!",
    "Unknown filetype" : "Үл мэдэгдэх файлын төрөл",
    "Invalid image" : "буруу зураг",
    "Avatar image is not square" : "Хөрөг зураг дөрвөлжин биш",
    "Files" : "файлууд",
    "today" : "өнөөдөр",
    "yesterday" : "өчигдөр",
    "last month" : "сүүлийн сар",
    "last year" : "сүүлийн жил",
    "seconds ago" : "секундийн өмнө",
    "File name is a reserved word" : "Файлын нэр нь нийцгүй  үг",
    "File name contains at least one invalid character" : "файлын нэр нь хамгийн багадаа нэг нь хүчингүй тэмдэгт агуулж байна",
    "File name is too long" : "Файлын нэр хэтэрхий урт байна",
    "Dot files are not allowed" : "Dot файлууд зөвшөөрөл байхгүй байна",
    "__language_name__" : "хэлний нэр",
    "Help" : "Туслах",
    "Apps" : "Аппликэйшинууд",
    "Settings" : "Тохиргоо",
    "Log out" : "гаргах",
    "Users" : "хэрэглэгч",
    "Email" : "Цахим шуудан",
    "Phone" : "Утас",
    "Twitter" : "Твиттер",
    "Website" : "Веб сайт",
    "Address" : "хаяг",
    "Profile picture" : "Профайл зураг",
    "About" : "Тухай",
    "Open »%s«" : "»%s« нээх",
    "Sunday" : "ням гариг",
    "Monday" : "даваа",
    "Tuesday" : "мягмар",
    "Wednesday" : "лхагва",
    "Thursday" : "пүрэв",
    "Friday" : "баасан",
    "Saturday" : "бямба",
    "June" : "Зургадугаар сар",
    "November" : "Арван нэгдүгээр сар",
    "a safe home for all your data" : "Таны өгөгдлүүдийн аюулгүй гэр",
    "Authentication error" : "Нотолгооны алдаа",
    "Storage is temporarily not available" : "Хадгалах төхөөрөмж нь түр хугацаанд ашиглах боломжгүй байна",
    "Full name" : "бүтэн нэр",
    "Unknown user" : "Тодорхойгүй хэрэглэгч"
},
"nplurals=2; plural=(n != 1);");
